<!--
https://pypi.org/project/readme-generator/
https://pypi.org/project/python-readme-generator/
-->

[![](https://img.shields.io/badge/OS-Unix-blue.svg?longCache=True)]()

#### Installation
```bash
$ [sudo] pip install temp-copy
```

#### Scripts usage
```bash
usage: temp-copy path
```

#### Examples
```bash
$ cd path/to/repo
$ temp-copy .
/var/folders/t8/6x3s8whx545fr5dx07k81y_r0000gn/T/tmp.8XKglxPU
```

<p align="center">
    <a href="https://pypi.org/project/python-readme-generator/">python-readme-generator</a>
</p>